git_remote_create: Create a New 'GitHub' Repository

View source: R/github.R

git_remote_createR Documentation

Create a New 'GitHub' Repository

Description

Given that a 'GitHub' user is configured, with the appropriate permissions, this function creates a new repository on your account.

Usage

git_remote_create(name, private = TRUE)

Arguments

name

Name of the repository to be created.

private

Whether or not the repository should be private, defaults to FALSE.

Value

Invisibly returns a logical value, indicating whether the function was successful or not.

Examples

## Not run: 
git_remote_create()

## End(Not run)

worcs documentation built on Feb. 22, 2026, 5:07 p.m.