The search starts at path, and recursively proceeds up the
directory hierarchy until a worcs project directory is found.
Examples
if(requireNamespace("withr", quietly = TRUE)){
withr::with_tempdir({
writeLines("", ".worcs")
worcs_root()
})
}
#> [1] "/tmp/RtmpD8RrQb/file22e52502c9a8"