- path
Character, indicating the directory in which to create the
'worcs' project. Default: 'worcs_project'.
- manuscript
Character, indicating what template to use for the
'R Markdown' manuscript. Default: 'APA6'. Available choices include
APA6 from the papaja package,
a github_document, and templates included in the
rticles package.
For more information, see add_manuscript.
- preregistration
Character, indicating what template to use for the
preregistration. Default: 'cos_prereg'. Available choices include:
"PSS", "Secondary", "None", and all templates from the
prereg package. For more information, see
add_preregistration.
- add_license
Character, indicating what license to include.
Default: 'ccby'. Available options include:
c("cc0", "ccby", "gpl", "gpl3", "agpl", "agpl3", "apache", "apl2",
"lgpl", "mit", "proprietary", "None". For more information, see
use_cc0_license.
- use_renv
Logical, indicating whether or not to use 'renv' to make the
project reproducible. Default: TRUE. See init.
- use_targets
Logical, indicating whether or not to use 'targets' to
create a Make-like pipeline.
Default: FALSE See targets-package.
- remote_repo
Character, URL of, or name for, the remote repository for
this project. If a URL of an existing repository is specified, it should have
the form
https://github.com[username][repo].git (preferred) or
git@[...].git (if using SSH).
Alternatively, a name for a new repository can be provided. If a 'GitHub'
user is authenticated on your device, this repository will be created on your
account.
Finally, a commit will
be made containing the 'README.md' file, and will be pushed to the remote
repository. Default: 'https', which results in no repository being created.
- verbose
Logical. Whether or not to print messages to the console
during project creation. Default: TRUE
- ...
Additional arguments passed to and from functions.